==> org.eclipse.osee.server.p2-0.26.0-SNAPSHOT.zip: org/eclipse/osee/orcs/db/internal/loader/data/OrcsObjectFactoryImpl.java <==
/*******************************************************************************
 * Copyright (c) 2012 Boeing.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Boeing - initial API and implementation
 *******************************************************************************/
package org.eclipse.osee.orcs.db.internal.loader.data;

import org.eclipse.osee.framework.core.data.ApplicabilityId;
import org.eclipse.osee.framework.core.data.ArtifactId;
import org.eclipse.osee.framework.core.data.AttributeTypeToken;
import org.eclipse.osee.framework.core.data.BranchId;
import org.eclipse.osee.framework.core.data.GammaId;
import org.eclipse.osee.framework.core.data.ArtifactTypeToken;
import org.eclipse.osee.framework.core.data.RelationTypeId;
import org.eclipse.osee.framework.core.data.RelationTypeToken;
import org.eclipse.osee.framework.core.data.RelationalConstants;
import org.eclipse.osee.framework.core.data.TransactionId;
import org.eclipse.osee.framework.core.data.Tuple2Type;
import org.eclipse.osee.framework.core.data.Tuple3Type;
import org.eclipse.osee.framework.core.data.Tuple4Type;
import org.eclipse.osee.framework.core.data.TupleTypeId;
import org.eclipse.osee.framework.core.enums.ModificationType;
import org.eclipse.osee.framework.jdk.core.util.Conditions;
import org.eclipse.osee.framework.jdk.core.util.Lib;
import org.eclipse.osee.orcs.core.ds.ArtifactData;
import org.eclipse.osee.orcs.core.ds.ArtifactDataImpl;
import org.eclipse.osee.orcs.core.ds.AttributeData;
import org.eclipse.osee.orcs.core.ds.DataProxy;
import org.eclipse.osee.orcs.core.ds.RelationData;
import org.eclipse.osee.orcs.core.ds.TupleData;
import org.eclipse.osee.orcs.core.ds.VersionData;
import org.eclipse.osee.orcs.core.ds.VersionDataImpl;
import org.eclipse.osee.orcs.data.ArtifactTypes;
import org.eclipse.osee.orcs.data.RelationTypes;
import org.eclipse.osee.orcs.db.internal.OrcsObjectFactory;
import org.eclipse.osee.orcs.db.internal.proxy.AttributeDataProxyFactory;

/**
 * @author Roberto E. Escobar
 */
public class OrcsObjectFactoryImpl implements OrcsObjectFactory {
   private final AttributeDataProxyFactory proxyFactory;
   private final RelationTypes relationTypes;
   private final ArtifactTypes artifactTypes;

   public OrcsObjectFactoryImpl(AttributeDataProxyFactory proxyFactory, RelationTypes relationTypes, ArtifactTypes artifactTypes) {
      this.proxyFactory = proxyFactory;
      this.relationTypes = relationTypes;
      this.artifactTypes = artifactTypes;
   }

   @Override
   public VersionData createVersion(BranchId branchId, TransactionId txId, GammaId gamma, boolean historical) {
      return createVersion(branchId, txId, gamma, historical, TransactionId.SENTINEL);
   }

   @Override
   public VersionData createDefaultVersionData() {
      // @formatter:off
      return createVersion(
         BranchId.SENTINEL,
         TransactionId.SENTINEL,
         GammaId.SENTINEL,
         RelationalConstants.IS_HISTORICAL_DEFAULT,
         TransactionId.SENTINEL);
      // @formatter:on
   }

   @Override
   public VersionData createCopy(VersionData other) {
      // @formatter:off
      return createVersion(
         other.getBranch(),
         other.getTransactionId(),
         other.getGammaId(),
         other.isHistorical(),
         other.getStripeId());
      // @formatter:on
   }

   private VersionData createVersion(BranchId branchId, TransactionId txId, GammaId gamma, boolean historical, TransactionId stripeId) {
      VersionData version = new VersionDataImpl();
      version.setBranch(branchId);
      version.setTransactionId(txId);
      version.setGammaId(gamma);
      version.setHistorical(historical);
      version.setStripeId(stripeId);
      return version;
   }

   @Override
   public ArtifactData createArtifactData(VersionData version, Integer generateArtId, ArtifactTypeToken artifactType, ModificationType modType, String guidToSet, ApplicabilityId applicId) {
      return createArtifactFromRow(version, generateArtId, artifactType, modType, artifactType, modType, guidToSet,
         applicId);
   }

   @Override
   public ArtifactData createCopy(ArtifactData source) {
      VersionData newVersion = createCopy(source.getVersion());
      return createArtifactFromRow(newVersion, source.getLocalId(), source.getType(), source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getGuid(), source.getApplicabilityId());
   }

   @Override
   public <T> AttributeData<T> createAttributeData(VersionData version, Integer id, AttributeTypeToken attributeType, ModificationType modType, ArtifactId artifactId, T value, String uri, ApplicabilityId applicId) {
      DataProxy<T> proxy = proxyFactory.createProxy(attributeType, value, uri);
      return createAttributeFromRow(version, id, attributeType, modType, attributeType, modType, artifactId, proxy,
         applicId);
   }

   @Override
   public <T> AttributeData<T> createCopy(AttributeData<T> source) {
      VersionData newVersion = createCopy(source.getVersion());
      AttributeTypeToken attributeType = source.getType();
      DataProxy<T> sourceProxy = source.getDataProxy();
      DataProxy<T> newProxy = proxyFactory.createProxy(attributeType, sourceProxy.getRawValue(), sourceProxy.getUri());
      return createAttributeFromRow(newVersion, source.getId().intValue(), attributeType, source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getArtifactId(), newProxy, source.getApplicabilityId());
   }

   @Override
   public <T> AttributeData<T> createAttributeData(VersionData version, Integer generateArtId, AttributeTypeToken attributeType, ModificationType modType, ArtifactId artId, ApplicabilityId applicId) {
      DataProxy<T> proxy = proxyFactory.createProxy(attributeType, "", "");
      return createAttributeFromRow(version, generateArtId, attributeType, modType, attributeType, modType, artId,
         proxy, applicId);
   }

   @Override
   public RelationData createRelationData(VersionData version, Integer id, RelationTypeToken relationType, ModificationType modType, ArtifactId aArtId, ArtifactId bArtId, String rationale, ApplicabilityId applicId) {
      return createRelationData(version, id, relationType, modType, relationType, modType, aArtId, bArtId, rationale,
         applicId);
   }

   @Override
   public RelationData createRelationData(VersionData version, Integer id, RelationTypeId relationType, ModificationType modType, ArtifactId aArtId, ArtifactId bArtId, String rationale, ApplicabilityId applicId) {
      return createRelationData(version, id, relationTypes.get(relationType), modType, aArtId, bArtId, rationale,
         applicId);
   }

   private ArtifactData createArtifactFromRow(VersionData version, int generateArtId, ArtifactTypeToken artifactType, ModificationType modType, ArtifactTypeToken baseArtifactType, ModificationType baseModType, String guid, ApplicabilityId applicId) {
      ArtifactData data = new ArtifactDataImpl(version);
      data.setLocalId(generateArtId);
      data.setType(artifactType);
      data.setBaseType(baseArtifactType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setGuid(guid);
      data.setApplicabilityId(applicId);
      return data;
   }

   private <T> AttributeData<T> createAttributeFromRow(VersionData version, int id, AttributeTypeToken attributeType, ModificationType modType, AttributeTypeToken baseAttributeType, ModificationType baseModType, ArtifactId artifactId, DataProxy<T> proxy, ApplicabilityId applicId) {
      AttributeData<T> data = new AttributeDataImpl<>(version);
      data.setLocalId(id);
      data.setType(attributeType);
      data.setBaseType(baseAttributeType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setArtifactId(artifactId);
      data.setDataProxy(proxy);
      data.setApplicabilityId(applicId);
      return data;
   }

   private RelationData createRelationData(VersionData version, Integer id, RelationTypeToken relationType, ModificationType modType, RelationTypeToken baseRelationType, ModificationType baseModType, ArtifactId aArtId, ArtifactId bArtId, String rationale, ApplicabilityId applicId) {
      RelationData data = new RelationDataImpl(version);
      data.setLocalId(id);
      data.setType(relationType);
      data.setBaseType(baseRelationType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setArtIdA(aArtId);
      data.setArtIdB(bArtId);
      Conditions.assertNotNull(rationale,
         "rationale can't be null for RelationData id [%s], type [%s], aArtId [%s], bArtId", id, relationType, aArtId,
         bArtId);
      data.setRationale(rationale);
      data.setApplicabilityId(applicId);
      return data;
   }

   @Override
   public RelationData createCopy(RelationData source) {
      VersionData newVersion = createCopy(source.getVersion());
      return createRelationData(newVersion, source.getLocalId(), source.getType(), source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getArtifactIdA(), source.getArtifactIdB(),
         source.getRationale(), source.getApplicabilityId());
   }

   private TupleData createTuple2Data(VersionData version, BranchId branch, TupleTypeId tupleType, Long e1, Long e2) {
      TupleData data = new TupleDataImpl(version);
      data.setBaseModType(ModificationType.NEW);
      data.setModType(ModificationType.NEW);
      data.setApplicabilityId(ApplicabilityId.BASE);
      data.setTupleType(tupleType);
      data.getVersion().setGammaId(GammaId.valueOf(Lib.generateUuid()));
      data.getVersion().setBranch(branch);
      data.setElement1(e1);
      data.setElement2(e2);
      return data;
   }

   @Override
   public TupleData createTuple2Data(VersionData version, BranchId branch, Tuple2Type<?, ?> tupleType, Long e1, Long e2) {
      return createTuple2Data(version, branch, (TupleTypeId) tupleType, e1, e2);
   }

   @Override
   public TupleData createTuple3Data(VersionData version, BranchId branch, Tuple3Type<?, ?, ?> tupleType, Long e1, Long e2, Long e3) {
      TupleData data = createTuple2Data(version, branch, tupleType, e1, e2);
      data.setElement3(e3);
      return data;
   }

   @Override
   public TupleData createTuple4Data(VersionData version, BranchId branch, Tuple4Type<?, ?, ?, ?> tupleType, Long e1, Long e2, Long e3, Long e4) {
      TupleData data = createTuple2Data(version, branch, tupleType, e1, e2);
      data.setElement3(e3);
      data.setElement4(e4);
      return data;
   }

   @Override
   public ArtifactData createArtifactData(VersionData version, Integer generateArtId, long artifactType, ModificationType modType, String guidToSet, ApplicabilityId applicId) {
      return createArtifactData(version, generateArtId, artifactTypes.get(artifactType), modType, guidToSet, applicId);
   }
}

==> org.eclipse.osee.server.p2-1.0.0-SNAPSHOT.zip: org/eclipse/osee/orcs/db/internal/loader/data/OrcsObjectFactoryImpl.java <==
/*********************************************************************
 * Copyright (c) 2012 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/

package org.eclipse.osee.orcs.db.internal.loader.data;

import org.eclipse.osee.framework.core.OrcsTokenService;
import org.eclipse.osee.framework.core.data.ApplicabilityId;
import org.eclipse.osee.framework.core.data.ArtifactId;
import org.eclipse.osee.framework.core.data.ArtifactTypeToken;
import org.eclipse.osee.framework.core.data.AttributeTypeGeneric;
import org.eclipse.osee.framework.core.data.AttributeTypeToken;
import org.eclipse.osee.framework.core.data.BranchId;
import org.eclipse.osee.framework.core.data.GammaId;
import org.eclipse.osee.framework.core.data.RelationTypeToken;
import org.eclipse.osee.framework.core.data.RelationalConstants;
import org.eclipse.osee.framework.core.data.TransactionId;
import org.eclipse.osee.framework.core.data.Tuple2Type;
import org.eclipse.osee.framework.core.data.Tuple3Type;
import org.eclipse.osee.framework.core.data.Tuple4Type;
import org.eclipse.osee.framework.core.data.TupleTypeId;
import org.eclipse.osee.framework.core.enums.ModificationType;
import org.eclipse.osee.framework.jdk.core.util.Lib;
import org.eclipse.osee.framework.jdk.core.util.Strings;
import org.eclipse.osee.orcs.core.ds.ArtifactData;
import org.eclipse.osee.orcs.core.ds.ArtifactDataImpl;
import org.eclipse.osee.orcs.core.ds.AttributeData;
import org.eclipse.osee.orcs.core.ds.DataProxy;
import org.eclipse.osee.orcs.core.ds.RelationData;
import org.eclipse.osee.orcs.core.ds.TupleData;
import org.eclipse.osee.orcs.core.ds.VersionData;
import org.eclipse.osee.orcs.core.ds.VersionDataImpl;
import org.eclipse.osee.orcs.db.internal.OrcsObjectFactory;
import org.eclipse.osee.orcs.db.internal.proxy.AttributeDataProxyFactory;

/**
 * @author Roberto E. Escobar
 */
public class OrcsObjectFactoryImpl implements OrcsObjectFactory {
   private final AttributeDataProxyFactory proxyFactory;
   private final OrcsTokenService tokenService;

   public OrcsObjectFactoryImpl(AttributeDataProxyFactory proxyFactory, OrcsTokenService tokenService) {
      this.proxyFactory = proxyFactory;
      this.tokenService = tokenService;
   }

   @Override
   public VersionData createVersion(BranchId branchId, TransactionId txId, GammaId gamma, boolean historical) {
      return createVersion(branchId, txId, gamma, historical, TransactionId.SENTINEL);
   }

   @Override
   public VersionData createDefaultVersionData() {
      // @formatter:off
      return createVersion(
         BranchId.SENTINEL,
         TransactionId.SENTINEL,
         GammaId.SENTINEL,
         RelationalConstants.IS_HISTORICAL_DEFAULT,
         TransactionId.SENTINEL);
      // @formatter:on
   }

   @Override
   public VersionData createCopy(VersionData other) {
      // @formatter:off
      return createVersion(
         other.getBranch(),
         other.getTransactionId(),
         other.getGammaId(),
         other.isHistorical(),
         other.getStripeId());
      // @formatter:on
   }

   private VersionData createVersion(BranchId branchId, TransactionId txId, GammaId gamma, boolean historical, TransactionId stripeId) {
      VersionData version = new VersionDataImpl();
      version.setBranch(branchId);
      version.setTransactionId(txId);
      version.setGammaId(gamma);
      version.setHistorical(historical);
      version.setStripeId(stripeId);
      return version;
   }

   @Override
   public ArtifactData createArtifactData(VersionData version, Integer generateArtId, ArtifactTypeToken artifactType, ModificationType modType, String guidToSet, ApplicabilityId applicId) {
      return createArtifactFromRow(version, generateArtId, artifactType, modType, artifactType, modType, guidToSet,
         applicId);
   }

   @Override
   public ArtifactData createCopy(ArtifactData source) {
      VersionData newVersion = createCopy(source.getVersion());
      return createArtifactFromRow(newVersion, source.getLocalId(), source.getType(), source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getGuid(), source.getApplicabilityId());
   }

   @Override
   public <T> AttributeData<T> createAttributeData(VersionData version, Integer id, AttributeTypeGeneric<?> attributeType, ModificationType modType, ArtifactId artifactId, T value, String uri, ApplicabilityId applicId) {
      DataProxy<T> proxy = proxyFactory.createProxy(attributeType, value, uri);
      return createAttributeFromRow(version, id, attributeType, modType, attributeType, modType, artifactId, proxy,
         applicId);
   }

   @Override
   public <T> AttributeData<T> createCopy(AttributeData<T> source) {
      VersionData newVersion = createCopy(source.getVersion());
      AttributeTypeGeneric<?> attributeType = tokenService.getAttributeType(source.getType().getId());
      DataProxy<T> sourceProxy = source.getDataProxy();
      DataProxy<T> newProxy = proxyFactory.createProxy(attributeType, sourceProxy.getRawValue(), sourceProxy.getUri());
      return createAttributeFromRow(newVersion, source.getId().intValue(), attributeType, source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getArtifactId(), newProxy, source.getApplicabilityId());
   }

   @Override
   public <T> AttributeData<T> createAttributeData(VersionData version, Integer generateArtId, AttributeTypeGeneric<?> attributeType, ModificationType modType, ArtifactId artId, ApplicabilityId applicId) {
      DataProxy<T> proxy = proxyFactory.createProxy(attributeType, "", "");
      return createAttributeFromRow(version, generateArtId, attributeType, modType, attributeType, modType, artId,
         proxy, applicId);
   }

   @Override
   public RelationData createRelationData(VersionData version, Integer id, RelationTypeToken relationType, ModificationType modType, ArtifactId aArtId, ArtifactId bArtId, String rationale, ApplicabilityId applicId) {
      return createRelationData(version, id, relationType, modType, relationType, modType, aArtId, bArtId, rationale,
         applicId);
   }

   private ArtifactData createArtifactFromRow(VersionData version, int generateArtId, ArtifactTypeToken artifactType, ModificationType modType, ArtifactTypeToken baseArtifactType, ModificationType baseModType, String guid, ApplicabilityId applicId) {
      ArtifactData data = new ArtifactDataImpl(version);
      data.setLocalId(generateArtId);
      data.setType(artifactType);
      data.setBaseType(baseArtifactType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setGuid(guid);
      data.setApplicabilityId(applicId);
      return data;
   }

   private <T> AttributeData<T> createAttributeFromRow(VersionData version, int id, AttributeTypeGeneric<?> attributeType, ModificationType modType, AttributeTypeToken baseAttributeType, ModificationType baseModType, ArtifactId artifactId, DataProxy<T> proxy, ApplicabilityId applicId) {
      AttributeData<T> data = new AttributeDataImpl<>(version);
      data.setLocalId(id);
      data.setType(attributeType);
      data.setBaseType(baseAttributeType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setArtifactId(artifactId);
      data.setDataProxy(proxy);
      data.setApplicabilityId(applicId);
      return data;
   }

   private RelationData createRelationData(VersionData version, Integer id, RelationTypeToken relationType, ModificationType modType, RelationTypeToken baseRelationType, ModificationType baseModType, ArtifactId aArtId, ArtifactId bArtId, String rationale, ApplicabilityId applicId) {
      RelationData data = new RelationDataImpl(version);
      data.setLocalId(id);
      data.setType(relationType);
      data.setBaseType(baseRelationType);
      data.setModType(modType);
      data.setBaseModType(baseModType);
      data.setArtIdA(aArtId);
      data.setArtIdB(bArtId);
      if (Strings.isValid(rationale)) {
         data.setRationale(rationale);
      }
      data.setApplicabilityId(applicId);
      return data;
   }

   @Override
   public RelationData createCopy(RelationData source) {
      VersionData newVersion = createCopy(source.getVersion());
      return createRelationData(newVersion, source.getLocalId(), source.getType(), source.getModType(),
         source.getBaseType(), source.getBaseModType(), source.getArtifactIdA(), source.getArtifactIdB(),
         source.getRationale(), source.getApplicabilityId());
   }

   private TupleData createTuple2Data(VersionData version, BranchId branch, TupleTypeId tupleType, Long e1, Long e2) {
      TupleData data = new TupleDataImpl(version);
      data.setBaseModType(ModificationType.NEW);
      data.setModType(ModificationType.NEW);
      data.setApplicabilityId(ApplicabilityId.BASE);
      data.setTupleType(tupleType);
      data.getVersion().setGammaId(GammaId.valueOf(Lib.generateUuid()));
      data.getVersion().setBranch(branch);
      data.setElement1(e1);
      data.setElement2(e2);
      return data;
   }

   @Override
   public TupleData createTuple2Data(VersionData version, BranchId branch, Tuple2Type<?, ?> tupleType, Long e1, Long e2) {
      return createTuple2Data(version, branch, (TupleTypeId) tupleType, e1, e2);
   }

   @Override
   public TupleData createTuple3Data(VersionData version, BranchId branch, Tuple3Type<?, ?, ?> tupleType, Long e1, Long e2, Long e3) {
      TupleData data = createTuple2Data(version, branch, tupleType, e1, e2);
      data.setElement3(e3);
      return data;
   }

   @Override
   public TupleData createTuple4Data(VersionData version, BranchId branch, Tuple4Type<?, ?, ?, ?> tupleType, Long e1, Long e2, Long e3, Long e4) {
      TupleData data = createTuple2Data(version, branch, tupleType, e1, e2);
      data.setElement3(e3);
      data.setElement4(e4);
      return data;
   }

   @Override
   public ArtifactData createArtifactData(VersionData version, Integer generateArtId, long artifactType, ModificationType modType, String guidToSet, ApplicabilityId applicId) {
      return createArtifactData(version, generateArtId, tokenService.getArtifactType(artifactType), modType, guidToSet,
         applicId);
   }
}
